Learn R Programming

agop (version 0.1-4)

get_incomparable_pairs: Get Incomparable Pairs in an Adjacency Matrix

Description

A pair (x,y) is incomparable iff not xRy and not xRy

Usage

get_incomparable_pairs(B)

Arguments

B

object of class igraph or a square 0-1 matrix of class Matrix or matrix

Value

integer matrix with two columns (indices of incomparable elements, not that these are pairs, and not sets: you'll get (i,j) and (j,i))

Details

See also get_independent_sets of how to generate all maximal independent sets.

See Also

Other binary_relations: closure_total_fair; closure_transitive; de_transitive; get_equivalence_classes; get_independent_sets; is_reflexive; is_total; is_transitive; pord_weakdom; rel_graph