index.g is a (deprecated) alias for index_g.
Note that index_g is not a zero-insensitive impact function,
see Examples section. index_g_zi is its zero-sensitive variant:
it assumes that the aggregated vector is padded with zeros.
The h-index is the same as the discrete Sugeno integral of x
w.r.t. the counting measure (cf. Torra, Narukawa, 2008).
If non-increasingly sorted vector is given, the function is O(n).
For historical reasons, this function is also available via its alias,
index.h [but its usage is deprecated].