Learn R Programming

agop (version 0.1-4)

index_lp: The l_p-index

Description

Given a sequence of \(n\) non-negative numbers \(x=(x_1,\dots,x_n)\), where \(x_i \ge x_j\) for \(i \le j\), the \(l_p\)-index for \(p=\infty\) equals to $$l_p(x)=\arg\max_{(i,x_i), i=1,\dots,n} \{ i x_i \}$$ if \(n \ge 1\), or \(l_\infty(x)=0\) otherwise. Note that if \((i,x_i)=l_\infty(x)\), then $$MAXPROD(x) = \mathtt{prod}(l_\infty(x)) = i x_i,$$ where \(MAXPROD\) is the index proposed in (Kosmulski, 2007), see index_maxprod.

For the definition of the \(l_p\)-index for \(p < \infty\) we refer to (Gagolewski, Grzegorzewski, 2009a).

Usage

index_lp(x, p = Inf, projection = prod)

index.lp(x, p = Inf, projection = prod) # deprecated alias

Arguments

x

a non-negative numeric vector

p

index order, \(p \in [1,\infty]\); defaults \(\infty\) (Inf).

projection

function

Value

result of projection(c(\(i, x_i\)))

Details

The \(l_p\)-index, by definition, is not an impact function, as it produces 2 numeric values. Thus, it should be projected to one dimension. However, you may set projection to identity to obtain the 2-dimensional index

If non-increasingly sorted vector is given, the function is O(n).

For historical reasons, this function is also available via its alias, index.lp [but its usage is deprecated].

References

Gagolewski M., Grzegorzewski P., A geometric approach to the construction of scientific impact indices, Scientometrics, 81(3), 2009a, pp. 617-634. Gagolewski M., Debski M., Nowakiewicz M., Efficient algorithms for computing ''geometric'' scientific impact indices, Research Report of Systems Research Institute, Polish Academy of Sciences RB/1/2009, 2009b. Kosmulski M., MAXPROD - A new index for assessment of the scientific output of an individual, and a comparison with the h-index, Cybermetrics, 11(1), 2007.

See Also

Other impact_functions: index.g, index_g, index_g_zi; index.h, index_h; index.rp, index_rp; index_maxprod; index_w

Examples

Run this code
# NOT RUN {
x <- runif(100, 0, 100)
index.lp(x, Inf, identity)  # two-dimensional value, can not be used
                            # directly in the analysis
index.lp(x, Inf, prod)      # the MAXPROD-index (one-dimensional) [default]
# }

Run the code above in your browser using DataLab