Learn R Programming

agop (version 0.1-3)

index_rp: The r_p-index

Description

Given a sequence of $n$ non-negative numbers $x=(x_1,\dots,x_n)$, where $x_i \ge x_j$ for $i \le j$, the $r_p$-index for $p=\infty$ equals to $$r_p(x)=\max_{i=1,\dots,n} { \min{i,x_i} }$$ if $n \ge 1$, or $r_\infty(x)=0$ otherwise. That is, it is equivalent to a particular OWMax operator, see owmax.

For the definition of the $r_p$-index for $p < \infty$ we refer to (Gagolewski, Grzegorzewski, 2009).

Usage

index_rp(x, p = Inf)

index.rp(x, p = Inf) # same as index_rp(x, p), deprecated alias

Arguments

x
a non-negative numeric vector
p
index order, $p \in [1,\infty]$; defaults $\infty$ (Inf).

Value

  • a single numeric value

Details

Note that if $x_1,\dots,x_n$ are integers, then $$r_\infty(x)=H(x),$$ where $H$ is the $h$-index (Hirsch, 2005) and $$r_1(x)=W(x),$$ where $W$ is the $w$-index (Woeginger, 2008), see index_h and index_w.

If non-increasingly sorted vector is given, the function is O(n).

For historical reasons, this function is also available via its alias, index.rp [but its usage is deprecated].

References

Gagolewski M., Grzegorzewski P., A geometric approach to the construction of scientific impact indices, Scientometrics, 81(3), 2009, pp. 617-634. Hirsch J.E., An index to quantify individual's scientific research output, Proceedings of the National Academy of Sciences 102(46), 16569-16572, 2005. Woeginger G.J., An axiomatic characterization of the Hirsch-index, Mathematical Social Sciences, 56(2), 224-232, 2008.

See Also

Other impact_functions: index_g, index_g_zi, index_h, index_lp, index_maxprod, index_w, index.g, index.h, index.lp

Examples

Run this code
x <- runif(100, 0, 100);
index.rp(x);            # the r_oo-index
floor(index.rp(x));     # the h-index
index.rp(floor(x), 1);  # the w-index

Run the code above in your browser using DataLab