Learn R Programming

agop (version 0.1-4)

is_reflexive: Check if Given Adjacency Matrix is Reflexive

Description

A binary relation R is reflexive, iff for all x we have \(xRx\). The function just checks whether all elements on the diagonal of B are non-zeros.

Usage

is_reflexive(B)

Arguments

B

object of class igraph or a square 0-1 matrix of class Matrix or matrix

Value

single logical value

See Also

Other binary_relations: closure_total_fair; closure_transitive; de_transitive; get_equivalence_classes; get_incomparable_pairs; get_independent_sets; is_total; is_transitive; pord_weakdom; rel_graph