Computes the Weghted Arithmetic Mean or the Ordered Weighted Averaging aggregation operator.
owa(x, w = rep(1/length(x), length(x)))wam(x, w = rep(1/length(x), length(x)))
numeric vector to be aggregated
numeric vector of the same length as x, with elements in \([0,1]\),
and such that \(\sum_i w_i=1\); weights
single numeric value
The OWA operator is given by
$$
\mathsf{OWA}_\mathtt{w}(\mathtt{x})=\sum_{i=1}^{n} w_{i}x_{\{i\}}
$$
where \(x_{\{i\}}\) denotes the \(i\)-th greatest
value in x.
The WAM operator is given by $$ \mathsf{WAM}_\mathtt{w}(\mathtt{x})=\sum_{i=1}^{n} w_{i}x_{i} $$
If the elements of w does not sum up to \(1\), then
they are normalized and a warning is generated.
Both functions return the ordinary arithmetic mean by default.
Special cases of OWA include the trimmed mean (cf. mean)
and winsorized mean.
There is a strong connection between the OWA operators and the Choquet integrals.
Yager R.R., On ordered weighted averaging aggregation operators in multicriteria decision making, IEEE Transactions on Systems, Man, and Cybernetics 18(1), 1988, pp. 183-190.