Learn R Programming

agop (version 0.1-3)

pareto2_estimate_mle: Parameter Estimation in the Pareto-II Distribution (MLE)

Description

Finds the maximum likelihood estimator of the type II Pareto distribution's shape parameter $k$ and, if not given explicitly, scale parameter $s$.

Usage

pareto2_estimate_mle(x, s = NA_real_, smin = 1e-04,
    smax = 20, tol = .Machine$double.eps^0.25)

Arguments

x
a non-negative numeric vector
s
a-priori known scale parameter, $s>0$ or NA if unknown (default)
smin
lower bound for the scale parameter to look for
smax
upper bound for the scale parameter to look for
tol
the desired accuracy (convergence tolerance)

Value

  • a numeric vector with the following named components:
    • k- estimated parameter of shape
    • s- estimated (or known, see thesargument) parameter of scale
    or c(NA, NA) if the maximum of the likelihood function could not be found.

Details

Note that if $s$ is not given, then the maximum of the likelihood function may not exist for some input vectors. This estimator may have large mean squared error. Consider using pareto2_estimate_mmse.

For known $s$, the estimator is unbiased.

See Also

Other Pareto2: dpareto2, pareto2_estimate_mmse, pareto2_test_f, ppareto2, qpareto2, rpareto2