Finds the MMS estimator of the type II Pareto distribution parameters using the Bayesian method (and the R code) developed by Zhang and Stevens (2009).
pareto2_estimate_mmse(x)a non-negative numeric vector
a numeric vector with the following named components:
k - estimated parameter of shape,
s - estimated parameter of scale.
Zhang J., Stevens M.A., A New and Efficient Estimation Method for the Generalized Pareto Distribution, Technometrics 51(3), 2009, 316-325.
Other Pareto2: dpareto2,
ppareto2, qpareto2,
rpareto2;
pareto2_estimate_mle;
pareto2_test_f