Learn R Programming

agop (version 0.1-3)

pareto2_test_f: Two-Sample F-test For Equality of Shape Parameters for Type II-Pareto Distributions

Description

Performs F-test for equality of shape parameters of two samples from the Pareto type-II distributions with known and equal scale parameters, $s>0$.

Usage

pareto2_test_f(x, y, s,
    alternative = c("two.sided", "less", "greater"),
    significance = NULL)

Arguments

x
a non-negative numeric vector
y
a non-negative numeric vector
s
the known scale parameter, $s>0$
alternative
indicates the alternative hypothesis and must be one of "two.sided" (default), "less", or "greater"
significance
significance level, $0<$significance$<1$ or="" NULL. See the Value section for details

Value

  • If significance is not NULL, then the list of class power.htest with the following components is passed as a result:
    • statistic- the value of the test statistic.
    • result- either FALSE (accept null hypothesis) or TRUE (reject).
    • alternative- a character string describing the alternative hypothesis.
    • method- a character string indicating what type of test was performed.
    • data.name- a character string giving the name(s) of the data.

    Otherwise, the list of class htest with the following components is passed as a result:

    • statisticthe value of the test statistic.
    • p.valuethe p-value of the test.
    • alternativea character string describing the alternative hypothesis.
    • methoda character string indicating what type of test was performed.
    • data.namea character string giving the name(s) of the data.

Details

Given two samples $(X_1,...,X_n)$ i.i.d. $P2(k_x,s)$ and $(Y_1,...,Y_m)$ i.i.d. $P2(k_y,s)$ this test verifies the null hypothesis $H_0: k_x=k_y$ against two-sided or one-sided alternatives, depending on the value of alternative. It bases on test statistic $T(X,Y)=\frac{n\sum_{i=1}^m\log(1+Y_i/m)}{m\sum_{i=1}^n\log(1+X_i/n)}$ which, under $H_0$, has the Snedecor's F distribution with $(2m, 2n)$ degrees of freedom.

Note that for $k_x < k_y$, then $X$ dominates $Y$ stochastically.

See Also

Other Pareto2: dpareto2, pareto2_estimate_mle, pareto2_estimate_mmse, ppareto2, qpareto2, rpareto2