Note that we assume that \(B\) is total, reflexive and transitive.
get_equivalence_classes(B)object of class igraph or a square
0-1 matrix of class Matrix or matrix
list of integer vectors; each list element defines an equivalence class by listing vertices' numbers; each vector is ordered by the outdegrees of their nodes (they are the same in each class)
Other binary_relations: closure_total_fair;
closure_transitive;
de_transitive;
get_incomparable_pairs;
get_independent_sets;
is_reflexive; is_total;
is_transitive; pord_weakdom;
rel_graph