Learn R Programming

agop (version 0.1-3)

index_g: Egghe's g-index

Description

Given a sequence of $n$ non-negative numbers $x=(x_1,\dots,x_n)$, where $x_i \ge x_j \ge 0$ for $i \le j$, the $g$-index (Egghe, 2006) for $x$ is defined as $$G(x)=\max{i=1,\dots,n: \sum_{j=1}^i x_i \ge i^2}$$ if $n \ge 1$ and $x_1 \ge 1$, or $G(x)=0$ otherwise.

Usage

index_g(x)

index.g(x) # same as index_g(x), deprecated alias

index_g_zi(x)

Arguments

x
a non-negative numeric vector

Value

  • a single numeric value

Details

index.g is a (deprecated) alias for index_g.

Note that index_g is not a zero-insensitive impact function, see Examples section. index_g_zi is its zero-sensitive variant: it assumes that the aggregated vector is padded with zeros.

The h-index is the same as the discrete Sugeno integral of x w.r.t. the counting measure (cf. Torra, Narukawa, 2008).

If non-increasingly sorted vector is given, the function is O(n).

For historical reasons, this function is also available via its alias, index.h [but its usage is deprecated].

References

Egghe L., Theory and practise of the g-index, Scientometrics 69(1), 131-152, 2006. Torra V., Narukawa Y., The h-index and the number of citations: Two fuzzy integrals. IEEE Transactions on Fuzzy Systems 16(3), 2008, 795-797.

See Also

Other impact_functions: index_h, index_lp, index_maxprod, index_rp, index_w, index.h, index.lp, index.rp

Examples

Run this code
sapply(list(c(9), c(9,0), c(9,0,0), c(9,0,0,0)), index_g) # not a zero-sensitive agop

Run the code above in your browser using DataLab