Learn R Programming

agop (version 0.1-4)

index_h: Hirsch's h-index

Description

Given a sequence of \(n\) non-negative numbers \(x=(x_1,\dots,x_n)\), where \(x_i \ge x_j \ge 0\) for \(i \le j\), the \(h\)-index (Hirsch, 2005) for \(x\) is defined as $$H(x)=\max\{i=1,\dots,n: x_i \ge i\}$$ if \(n \ge 1\) and \(x_1 \ge 1\), or \(H(x)=0\) otherwise.

Usage

index_h(x)

index.h(x) # same as index_h(x), deprecated alias

Arguments

x

a non-negative numeric vector

Value

a single numeric value

Details

If non-increasingly sorted vector is given, the function is O(n).

For historical reasons, this function is also available via its alias, index.h [but its usage is deprecated].

See index_rp and owmax for natural generalizations.

References

Hirsch J.E., An index to quantify individual's scientific research output, Proceedings of the National Academy of Sciences 102(46), 16569-16572, 2005.

See Also

Other impact_functions: index.g, index_g, index_g_zi; index.lp, index_lp; index.rp, index_rp; index_maxprod; index_w

Examples

Run this code
# NOT RUN {
authors <- list(  # a list of numeric sequences
                  # (e.g. citation counts of the articles
                  # written by some authors)
    "A" =c(23,21,4,2,1,0,0),
    "B" =c(11,5,4,4,3,2,2,2,2,2,1,1,1,0,0,0,0),
    "C" =c(53,43,32,23,14,13,12,8,4,3,2,1,0)
 )
index_h(authors$A)
sapply(authors, index_h)
# }

Run the code above in your browser using DataLab