Given a sequence of \(n\) non-negative numbers \(x=(x_1,\dots,x_n)\), where \(x_i \ge x_j \ge 0\) for \(i \le j\), the MAXPROD-index (Kosmulski, 2007) for \(x\) is defined as $$MAXPROD(x)=\max\{i x_i: i=1,\dots,n\}$$
index_maxprod(x)a non-negative numeric vector
a single numeric value
If non-increasingly sorted vector is given, the function is O(n).
MAXPROD index is the same as the discrete Shilkret integral of x
w.r.t. the counting measure.
See index_lp for a natural generalization.
Kosmulski M., MAXPROD - A new index for assessment of the scientific output of an individual, and a comparison with the h-index, Cybermetrics 11(1), 2007.
Other impact_functions: index.g,
index_g, index_g_zi;
index.h, index_h;
index.lp, index_lp;
index.rp, index_rp;
index_w