Learn R Programming

agop (version 0.1-3)

pareto2_estimate_mmse: Parameter Estimation in the Pareto-II Distribution (MMSE)

Description

Finds the MMS estimator of the type II Pareto distribution parameters using the Bayesian method (and the R code) developed by Zhang and Stevens (2009).

Usage

pareto2_estimate_mmse(x)

Arguments

x
a non-negative numeric vector

Value

  • a numeric vector with the following named components:
    • k- estimated parameter of shape,
    • s- estimated parameter of scale.

References

Zhang J., Stevens M.A., A New and Efficient Estimation Method for the Generalized Pareto Distribution, Technometrics 51(3), 2009, 316-325.

See Also

Other Pareto2: dpareto2, pareto2_estimate_mle, pareto2_test_f, ppareto2, qpareto2, rpareto2